@@ -28,19 +28,28 @@
 #include <aws/s3tables/model/GetTableBucketMaintenanceConfigurationResult.h>
 #include <aws/s3tables/model/GetTableBucketMetricsConfigurationResult.h>
 #include <aws/s3tables/model/GetTableBucketPolicyResult.h>
+#include <aws/s3tables/model/GetTableBucketReplicationResult.h>
 #include <aws/s3tables/model/GetTableBucketResult.h>
+#include <aws/s3tables/model/GetTableBucketStorageClassResult.h>
 #include <aws/s3tables/model/GetTableEncryptionResult.h>
 #include <aws/s3tables/model/GetTableMaintenanceConfigurationResult.h>
 #include <aws/s3tables/model/GetTableMaintenanceJobStatusResult.h>
 #include <aws/s3tables/model/GetTableMetadataLocationResult.h>
 #include <aws/s3tables/model/GetTablePolicyResult.h>
+#include <aws/s3tables/model/GetTableRecordExpirationConfigurationResult.h>
+#include <aws/s3tables/model/GetTableRecordExpirationJobStatusResult.h>
+#include <aws/s3tables/model/GetTableReplicationResult.h>
+#include <aws/s3tables/model/GetTableReplicationStatusResult.h>
 #include <aws/s3tables/model/GetTableRequest.h>
 #include <aws/s3tables/model/GetTableResult.h>
+#include <aws/s3tables/model/GetTableStorageClassResult.h>
 #include <aws/s3tables/model/ListNamespacesResult.h>
 #include <aws/s3tables/model/ListTableBucketsRequest.h>
 #include <aws/s3tables/model/ListTableBucketsResult.h>
 #include <aws/s3tables/model/ListTablesResult.h>
 #include <aws/s3tables/model/ListTagsForResourceResult.h>
+#include <aws/s3tables/model/PutTableBucketReplicationResult.h>
+#include <aws/s3tables/model/PutTableReplicationResult.h>
 #include <aws/s3tables/model/TagResourceResult.h>
 #include <aws/s3tables/model/UntagResourceResult.h>
 #include <aws/s3tables/model/UpdateTableMetadataLocationResult.h>
@@ -86,7 +95,9 @@ class DeleteTableBucketRequest;
 class DeleteTableBucketEncryptionRequest;
 class DeleteTableBucketMetricsConfigurationRequest;
 class DeleteTableBucketPolicyRequest;
+class DeleteTableBucketReplicationRequest;
 class DeleteTablePolicyRequest;
+class DeleteTableReplicationRequest;
 class GetNamespaceRequest;
 class GetTableRequest;
 class GetTableBucketRequest;
@@ -94,11 +105,18 @@ class GetTableBucketEncryptionRequest;
 class GetTableBucketMaintenanceConfigurationRequest;
 class GetTableBucketMetricsConfigurationRequest;
 class GetTableBucketPolicyRequest;
+class GetTableBucketReplicationRequest;
+class GetTableBucketStorageClassRequest;
 class GetTableEncryptionRequest;
 class GetTableMaintenanceConfigurationRequest;
 class GetTableMaintenanceJobStatusRequest;
 class GetTableMetadataLocationRequest;
 class GetTablePolicyRequest;
+class GetTableRecordExpirationConfigurationRequest;
+class GetTableRecordExpirationJobStatusRequest;
+class GetTableReplicationRequest;
+class GetTableReplicationStatusRequest;
+class GetTableStorageClassRequest;
 class ListNamespacesRequest;
 class ListTableBucketsRequest;
 class ListTablesRequest;
@@ -107,8 +125,12 @@ class PutTableBucketEncryptionRequest;
 class PutTableBucketMaintenanceConfigurationRequest;
 class PutTableBucketMetricsConfigurationRequest;
 class PutTableBucketPolicyRequest;
+class PutTableBucketReplicationRequest;
+class PutTableBucketStorageClassRequest;
 class PutTableMaintenanceConfigurationRequest;
 class PutTablePolicyRequest;
+class PutTableRecordExpirationConfigurationRequest;
+class PutTableReplicationRequest;
 class RenameTableRequest;
 class TagResourceRequest;
 class UntagResourceRequest;
@@ -125,7 +147,9 @@ typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableBucketOutco
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableBucketEncryptionOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableBucketMetricsConfigurationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableBucketPolicyOutcome;
+typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableBucketReplicationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTablePolicyOutcome;
+typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> DeleteTableReplicationOutcome;
 typedef Aws::Utils::Outcome<GetNamespaceResult, S3TablesError> GetNamespaceOutcome;
 typedef Aws::Utils::Outcome<GetTableResult, S3TablesError> GetTableOutcome;
 typedef Aws::Utils::Outcome<GetTableBucketResult, S3TablesError> GetTableBucketOutcome;
@@ -133,11 +157,18 @@ typedef Aws::Utils::Outcome<GetTableBucketEncryptionResult, S3TablesError> GetTa
 typedef Aws::Utils::Outcome<GetTableBucketMaintenanceConfigurationResult, S3TablesError> GetTableBucketMaintenanceConfigurationOutcome;
 typedef Aws::Utils::Outcome<GetTableBucketMetricsConfigurationResult, S3TablesError> GetTableBucketMetricsConfigurationOutcome;
 typedef Aws::Utils::Outcome<GetTableBucketPolicyResult, S3TablesError> GetTableBucketPolicyOutcome;
+typedef Aws::Utils::Outcome<GetTableBucketReplicationResult, S3TablesError> GetTableBucketReplicationOutcome;
+typedef Aws::Utils::Outcome<GetTableBucketStorageClassResult, S3TablesError> GetTableBucketStorageClassOutcome;
 typedef Aws::Utils::Outcome<GetTableEncryptionResult, S3TablesError> GetTableEncryptionOutcome;
 typedef Aws::Utils::Outcome<GetTableMaintenanceConfigurationResult, S3TablesError> GetTableMaintenanceConfigurationOutcome;
 typedef Aws::Utils::Outcome<GetTableMaintenanceJobStatusResult, S3TablesError> GetTableMaintenanceJobStatusOutcome;
 typedef Aws::Utils::Outcome<GetTableMetadataLocationResult, S3TablesError> GetTableMetadataLocationOutcome;
 typedef Aws::Utils::Outcome<GetTablePolicyResult, S3TablesError> GetTablePolicyOutcome;
+typedef Aws::Utils::Outcome<GetTableRecordExpirationConfigurationResult, S3TablesError> GetTableRecordExpirationConfigurationOutcome;
+typedef Aws::Utils::Outcome<GetTableRecordExpirationJobStatusResult, S3TablesError> GetTableRecordExpirationJobStatusOutcome;
+typedef Aws::Utils::Outcome<GetTableReplicationResult, S3TablesError> GetTableReplicationOutcome;
+typedef Aws::Utils::Outcome<GetTableReplicationStatusResult, S3TablesError> GetTableReplicationStatusOutcome;
+typedef Aws::Utils::Outcome<GetTableStorageClassResult, S3TablesError> GetTableStorageClassOutcome;
 typedef Aws::Utils::Outcome<ListNamespacesResult, S3TablesError> ListNamespacesOutcome;
 typedef Aws::Utils::Outcome<ListTableBucketsResult, S3TablesError> ListTableBucketsOutcome;
 typedef Aws::Utils::Outcome<ListTablesResult, S3TablesError> ListTablesOutcome;
@@ -146,8 +177,12 @@ typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableBucketEncrypti
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableBucketMaintenanceConfigurationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableBucketMetricsConfigurationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableBucketPolicyOutcome;
+typedef Aws::Utils::Outcome<PutTableBucketReplicationResult, S3TablesError> PutTableBucketReplicationOutcome;
+typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableBucketStorageClassOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableMaintenanceConfigurationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTablePolicyOutcome;
+typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> PutTableRecordExpirationConfigurationOutcome;
+typedef Aws::Utils::Outcome<PutTableReplicationResult, S3TablesError> PutTableReplicationOutcome;
 typedef Aws::Utils::Outcome<Aws::NoResult, S3TablesError> RenameTableOutcome;
 typedef Aws::Utils::Outcome<TagResourceResult, S3TablesError> TagResourceOutcome;
 typedef Aws::Utils::Outcome<UntagResourceResult, S3TablesError> UntagResourceOutcome;
@@ -164,7 +199,9 @@ typedef std::future<DeleteTableBucketOutcome> DeleteTableBucketOutcomeCallable;
 typedef std::future<DeleteTableBucketEncryptionOutcome> DeleteTableBucketEncryptionOutcomeCallable;
 typedef std::future<DeleteTableBucketMetricsConfigurationOutcome> DeleteTableBucketMetricsConfigurationOutcomeCallable;
 typedef std::future<DeleteTableBucketPolicyOutcome> DeleteTableBucketPolicyOutcomeCallable;
+typedef std::future<DeleteTableBucketReplicationOutcome> DeleteTableBucketReplicationOutcomeCallable;
 typedef std::future<DeleteTablePolicyOutcome> DeleteTablePolicyOutcomeCallable;
+typedef std::future<DeleteTableReplicationOutcome> DeleteTableReplicationOutcomeCallable;
 typedef std::future<GetNamespaceOutcome> GetNamespaceOutcomeCallable;
 typedef std::future<GetTableOutcome> GetTableOutcomeCallable;
 typedef std::future<GetTableBucketOutcome> GetTableBucketOutcomeCallable;
@@ -172,11 +209,18 @@ typedef std::future<GetTableBucketEncryptionOutcome> GetTableBucketEncryptionOut
 typedef std::future<GetTableBucketMaintenanceConfigurationOutcome> GetTableBucketMaintenanceConfigurationOutcomeCallable;
 typedef std::future<GetTableBucketMetricsConfigurationOutcome> GetTableBucketMetricsConfigurationOutcomeCallable;
 typedef std::future<GetTableBucketPolicyOutcome> GetTableBucketPolicyOutcomeCallable;
+typedef std::future<GetTableBucketReplicationOutcome> GetTableBucketReplicationOutcomeCallable;
+typedef std::future<GetTableBucketStorageClassOutcome> GetTableBucketStorageClassOutcomeCallable;
 typedef std::future<GetTableEncryptionOutcome> GetTableEncryptionOutcomeCallable;
 typedef std::future<GetTableMaintenanceConfigurationOutcome> GetTableMaintenanceConfigurationOutcomeCallable;
 typedef std::future<GetTableMaintenanceJobStatusOutcome> GetTableMaintenanceJobStatusOutcomeCallable;
 typedef std::future<GetTableMetadataLocationOutcome> GetTableMetadataLocationOutcomeCallable;
 typedef std::future<GetTablePolicyOutcome> GetTablePolicyOutcomeCallable;
+typedef std::future<GetTableRecordExpirationConfigurationOutcome> GetTableRecordExpirationConfigurationOutcomeCallable;
+typedef std::future<GetTableRecordExpirationJobStatusOutcome> GetTableRecordExpirationJobStatusOutcomeCallable;
+typedef std::future<GetTableReplicationOutcome> GetTableReplicationOutcomeCallable;
+typedef std::future<GetTableReplicationStatusOutcome> GetTableReplicationStatusOutcomeCallable;
+typedef std::future<GetTableStorageClassOutcome> GetTableStorageClassOutcomeCallable;
 typedef std::future<ListNamespacesOutcome> ListNamespacesOutcomeCallable;
 typedef std::future<ListTableBucketsOutcome> ListTableBucketsOutcomeCallable;
 typedef std::future<ListTablesOutcome> ListTablesOutcomeCallable;
@@ -185,8 +229,12 @@ typedef std::future<PutTableBucketEncryptionOutcome> PutTableBucketEncryptionOut
 typedef std::future<PutTableBucketMaintenanceConfigurationOutcome> PutTableBucketMaintenanceConfigurationOutcomeCallable;
 typedef std::future<PutTableBucketMetricsConfigurationOutcome> PutTableBucketMetricsConfigurationOutcomeCallable;
 typedef std::future<PutTableBucketPolicyOutcome> PutTableBucketPolicyOutcomeCallable;
+typedef std::future<PutTableBucketReplicationOutcome> PutTableBucketReplicationOutcomeCallable;
+typedef std::future<PutTableBucketStorageClassOutcome> PutTableBucketStorageClassOutcomeCallable;
 typedef std::future<PutTableMaintenanceConfigurationOutcome> PutTableMaintenanceConfigurationOutcomeCallable;
 typedef std::future<PutTablePolicyOutcome> PutTablePolicyOutcomeCallable;
+typedef std::future<PutTableRecordExpirationConfigurationOutcome> PutTableRecordExpirationConfigurationOutcomeCallable;
+typedef std::future<PutTableReplicationOutcome> PutTableReplicationOutcomeCallable;
 typedef std::future<RenameTableOutcome> RenameTableOutcomeCallable;
 typedef std::future<TagResourceOutcome> TagResourceOutcomeCallable;
 typedef std::future<UntagResourceOutcome> UntagResourceOutcomeCallable;
@@ -225,9 +273,16 @@ typedef std::function<void(const S3TablesClient*, const Model::DeleteTableBucket
 typedef std::function<void(const S3TablesClient*, const Model::DeleteTableBucketPolicyRequest&,
                            const Model::DeleteTableBucketPolicyOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     DeleteTableBucketPolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::DeleteTableBucketReplicationRequest&,
+                           const Model::DeleteTableBucketReplicationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    DeleteTableBucketReplicationResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::DeleteTablePolicyRequest&, const Model::DeleteTablePolicyOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     DeleteTablePolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::DeleteTableReplicationRequest&, const Model::DeleteTableReplicationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    DeleteTableReplicationResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::GetNamespaceRequest&, const Model::GetNamespaceOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     GetNamespaceResponseReceivedHandler;
@@ -251,6 +306,12 @@ typedef std::function<void(const S3TablesClient*, const Model::GetTableBucketMet
 typedef std::function<void(const S3TablesClient*, const Model::GetTableBucketPolicyRequest&, const Model::GetTableBucketPolicyOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     GetTableBucketPolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableBucketReplicationRequest&,
+                           const Model::GetTableBucketReplicationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableBucketReplicationResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableBucketStorageClassRequest&,
+                           const Model::GetTableBucketStorageClassOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableBucketStorageClassResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::GetTableEncryptionRequest&, const Model::GetTableEncryptionOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     GetTableEncryptionResponseReceivedHandler;
@@ -268,6 +329,23 @@ typedef std::function<void(const S3TablesClient*, const Model::GetTableMetadataL
 typedef std::function<void(const S3TablesClient*, const Model::GetTablePolicyRequest&, const Model::GetTablePolicyOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     GetTablePolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableRecordExpirationConfigurationRequest&,
+                           const Model::GetTableRecordExpirationConfigurationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableRecordExpirationConfigurationResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableRecordExpirationJobStatusRequest&,
+                           const Model::GetTableRecordExpirationJobStatusOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableRecordExpirationJobStatusResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableReplicationRequest&, const Model::GetTableReplicationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableReplicationResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableReplicationStatusRequest&,
+                           const Model::GetTableReplicationStatusOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableReplicationStatusResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::GetTableStorageClassRequest&, const Model::GetTableStorageClassOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    GetTableStorageClassResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::ListNamespacesRequest&, const Model::ListNamespacesOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     ListNamespacesResponseReceivedHandler;
@@ -294,6 +372,12 @@ typedef std::function<void(const S3TablesClient*, const Model::PutTableBucketMet
 typedef std::function<void(const S3TablesClient*, const Model::PutTableBucketPolicyRequest&, const Model::PutTableBucketPolicyOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     PutTableBucketPolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::PutTableBucketReplicationRequest&,
+                           const Model::PutTableBucketReplicationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    PutTableBucketReplicationResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::PutTableBucketStorageClassRequest&,
+                           const Model::PutTableBucketStorageClassOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    PutTableBucketStorageClassResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::PutTableMaintenanceConfigurationRequest&,
                            const Model::PutTableMaintenanceConfigurationOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
@@ -301,6 +385,13 @@ typedef std::function<void(const S3TablesClient*, const Model::PutTableMaintenan
 typedef std::function<void(const S3TablesClient*, const Model::PutTablePolicyRequest&, const Model::PutTablePolicyOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     PutTablePolicyResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::PutTableRecordExpirationConfigurationRequest&,
+                           const Model::PutTableRecordExpirationConfigurationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    PutTableRecordExpirationConfigurationResponseReceivedHandler;
+typedef std::function<void(const S3TablesClient*, const Model::PutTableReplicationRequest&, const Model::PutTableReplicationOutcome&,
+                           const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
+    PutTableReplicationResponseReceivedHandler;
 typedef std::function<void(const S3TablesClient*, const Model::RenameTableRequest&, const Model::RenameTableOutcome&,
                            const std::shared_ptr<const Aws::Client::AsyncCallerContext>&)>
     RenameTableResponseReceivedHandler;
